Examples
========

Parallel, ordered map and gather
--------------------------------

.. literalinclude:: examples/parallel_map.py


Async parallel processing pipeline
----------------------------------

.. literalinclude:: examples/async_parallel_pipeline.py


Single use workers
------------------

.. literalinclude:: examples/single_use_workers.py